==> payara-embedded-web-4.1.2.172-sources.jar: fish/payara/appserver/zendesk/admin/SetZendeskSupportConfigurationCommand.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) [2017] Payara Foundation and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://github.com/payara/Payara/blob/master/LICENSE.txt
 * See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * The Payara Foundation designates this particular file as subject to the "Classpath"
 * exception as provided by the Payara Foundation in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package fish.payara.appserver.zendesk.admin;

import com.sun.enterprise.config.serverbeans.Config;
import fish.payara.appserver.zendesk.ZendeskSupportService;
import fish.payara.appserver.zendesk.config.ZendeskSupportConfiguration;
import java.util.logging.Logger;
import javax.inject.Inject;
import org.glassfish.api.ActionReport;
import org.glassfish.api.Param;
import org.glassfish.api.admin.AdminCommand;
import org.glassfish.api.admin.AdminCommandContext;
import org.glassfish.api.admin.ExecuteOn;
import org.glassfish.api.admin.RestEndpoint;
import org.glassfish.api.admin.RestEndpoints;
import org.glassfish.api.admin.RuntimeType;
import org.glassfish.hk2.api.PerLookup;
import org.glassfish.internal.api.Target;
import org.jvnet.hk2.annotations.Service;
import org.jvnet.hk2.config.ConfigSupport;
import org.jvnet.hk2.config.SingleConfigCode;
import org.jvnet.hk2.config.TransactionFailure;

/**
 *
 * @author Andrew Pielage
 */
@Service(name = "set-zendesk-support-configuration")
@PerLookup
@ExecuteOn(RuntimeType.DAS)
@RestEndpoints({
    @RestEndpoint(configBean = ZendeskSupportConfiguration.class,
            opType = RestEndpoint.OpType.POST,
            path = "set-zendesk-support-configuration",
            description = "Sets the Zendesk Support Configuration")
})
public class SetZendeskSupportConfigurationCommand implements AdminCommand {

    @Inject
    private Target targetUtil;
    
    @Inject
    ZendeskSupportService zendeskSupport;
    
    @Param(name = "emailAddress", alias = "emailaddress")
    private String emailAddress;
    
    private final String target = "server-config";
    
    @Override
    public void execute(AdminCommandContext acc) {
        Config config = targetUtil.getConfig(target);
        ActionReport actionReport = acc.getActionReport();
        
        ZendeskSupportConfiguration zendeskSupportConfiguration = 
                config.getExtensionByType(ZendeskSupportConfiguration.class);
        
        if (zendeskSupportConfiguration != null) {
            try {
                ConfigSupport.apply(new SingleConfigCode<ZendeskSupportConfiguration>(){
                    @Override
                    public Object run(ZendeskSupportConfiguration config) {
                        config.setEmailAddress(emailAddress);
                        return null;
                    }
                }, zendeskSupportConfiguration);
            } catch (TransactionFailure ex) {
                // Set failure
                actionReport.failure(Logger.getLogger(SetZendeskSupportConfigurationCommand.class.getName()), 
                        "Failed to update configuration", ex);
            }
        }
    }
}

==> payara-embedded-web-5.192-sources.jar: fish/payara/appserver/zendesk/admin/SetZendeskSupportConfigurationCommand.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) [2017-2018] Payara Foundation and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://github.com/payara/Payara/blob/master/LICENSE.txt
 * See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * The Payara Foundation designates this particular file as subject to the "Classpath"
 * exception as provided by the Payara Foundation in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package fish.payara.appserver.zendesk.admin;

import com.google.common.base.Strings;
import com.sun.enterprise.config.serverbeans.Config;
import fish.payara.appserver.zendesk.ZendeskSupportService;
import fish.payara.appserver.zendesk.config.ZendeskSupportConfiguration;
import java.util.logging.Logger;
import javax.inject.Inject;
import org.glassfish.api.ActionReport;
import org.glassfish.api.Param;
import org.glassfish.api.admin.AdminCommand;
import org.glassfish.api.admin.AdminCommandContext;
import org.glassfish.api.admin.ExecuteOn;
import org.glassfish.api.admin.RestEndpoint;
import org.glassfish.api.admin.RestEndpoints;
import org.glassfish.api.admin.RuntimeType;
import org.glassfish.hk2.api.PerLookup;
import org.glassfish.internal.api.Target;
import org.jvnet.hk2.annotations.Service;
import org.jvnet.hk2.config.ConfigSupport;
import org.jvnet.hk2.config.SingleConfigCode;
import org.jvnet.hk2.config.TransactionFailure;

/**
 *
 * @author Andrew Pielage
 */
@Service(name = "set-zendesk-support-configuration")
@PerLookup
@ExecuteOn(RuntimeType.DAS)
@RestEndpoints({
    @RestEndpoint(configBean = ZendeskSupportConfiguration.class,
            opType = RestEndpoint.OpType.POST,
            path = "set-zendesk-support-configuration",
            description = "Sets the Zendesk Support Configuration")
})
public class SetZendeskSupportConfigurationCommand implements AdminCommand {

    @Inject
    private Target targetUtil;
    
    @Inject
    private ZendeskSupportService zendeskSupport;
    
    @Param(name = "emailAddress", alias = "emailaddress", optional = true)
    private String emailAddress;
    
    @Param(name="enabled", optional = true)
    private Boolean enabled;
    
    private final String target = "server-config";
    
    @Override
    public void execute(AdminCommandContext acc) {
        Config config = targetUtil.getConfig(target);
        ActionReport actionReport = acc.getActionReport();
        
        ZendeskSupportConfiguration zendeskSupportConfiguration = 
                config.getExtensionByType(ZendeskSupportConfiguration.class);
        
        if (zendeskSupportConfiguration != null) {
            try {
                ConfigSupport.apply(new SingleConfigCode<ZendeskSupportConfiguration>(){
                    @Override
                    public Object run(ZendeskSupportConfiguration config) {
                        
                         if(enabled != null) {
                            config.setEnabled(Boolean.toString(enabled));
                        }
                         if (!Strings.isNullOrEmpty(emailAddress)){
                             config.setEmailAddress(emailAddress);
                         }
                        
                        return null;
                    }
                }, zendeskSupportConfiguration);
            } catch (TransactionFailure ex) {
                // Set failure
                actionReport.failure(Logger.getLogger(SetZendeskSupportConfigurationCommand.class.getName()), 
                        "Failed to update configuration", ex);
            }
        }
    }
}
